@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 2014-2018 Free Software Foundation, Inc.
+# Copyright (C) 2014-2023 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,9 +19,9 @@ srcdir=${srcdir:-.}
 
 run_ginfo -f intera -n 'Goal column'
 
-printf '/^Goal column test\r\016' >$pty_type
-printf '\005\016\016\006\006' >$pty_type
-printf '\rDq' >$pty_type
+printf '/^Goal column test\r\016' >&7
+printf '\005\016\016\006\006' >&7
+printf '\rDq' >&7
 timeout_test
 
 diff $ginfo_output $t/node-target
