@@ -25,9 +25,11 @@ $result_trees{'node_up_external_node'} = [
                 'text' => 'Top'
               }
             ],
-            'extra' => {
-              'spaces_after_argument' => '
+            'info' => {
+              'spaces_after_argument' => {
+                'text' => '
 '
+              }
             },
             'type' => 'line_arg'
           }
@@ -42,9 +44,11 @@ $result_trees{'node_up_external_node'} = [
           {
             'args' => [
               {
-                'extra' => {
-                  'spaces_after_argument' => '
+                'info' => {
+                  'spaces_after_argument' => {
+                    'text' => '
 '
+                  }
                 },
                 'type' => 'block_line_arg'
               }
@@ -52,7 +56,7 @@ $result_trees{'node_up_external_node'} = [
             'cmdname' => 'menu',
             'contents' => [
               {
-                'args' => [
+                'contents' => [
                   {
                     'text' => '* ',
                     'type' => 'menu_entry_leading_text'
@@ -60,9 +64,15 @@ $result_trees{'node_up_external_node'} = [
                   {
                     'contents' => [
                       {
-                        'text' => 'first'
+                        'text' => 'chap first'
                       }
                     ],
+                    'extra' => {
+                      'node_content' => [
+                        {}
+                      ],
+                      'normalized' => 'chap-first'
+                    },
                     'type' => 'menu_entry_node'
                   },
                   {
@@ -84,15 +94,6 @@ $result_trees{'node_up_external_node'} = [
                     'type' => 'menu_entry_description'
                   }
                 ],
-                'extra' => {
-                  'menu_entry_description' => {},
-                  'menu_entry_node' => {
-                    'node_content' => [
-                      {}
-                    ],
-                    'normalized' => 'first'
-                  }
-                },
                 'source_info' => {
                   'file_name' => '',
                   'line_nr' => 4,
@@ -108,18 +109,24 @@ $result_trees{'node_up_external_node'} = [
                         'text' => 'menu'
                       }
                     ],
-                    'extra' => {
-                      'spaces_after_argument' => '
+                    'info' => {
+                      'spaces_after_argument' => {
+                        'text' => '
 '
+                      }
                     },
                     'type' => 'line_arg'
                   }
                 ],
                 'cmdname' => 'end',
                 'extra' => {
-                  'spaces_before_argument' => ' ',
                   'text_arg' => 'menu'
                 },
+                'info' => {
+                  'spaces_before_argument' => {
+                    'text' => ' '
+                  }
+                },
                 'source_info' => {
                   'file_name' => '',
                   'line_nr' => 5,
@@ -140,19 +147,12 @@ $result_trees{'node_up_external_node'} = [
           }
         ],
         'extra' => {
-          'node_content' => [
-            {}
-          ],
-          'nodes_manuals' => [
-            {
-              'node_content' => [
-                {}
-              ],
-              'normalized' => 'Top'
-            }
-          ],
-          'normalized' => 'Top',
-          'spaces_before_argument' => ' '
+          'normalized' => 'Top'
+        },
+        'info' => {
+          'spaces_before_argument' => {
+            'text' => ' '
+          }
         },
         'source_info' => {
           'file_name' => '',
@@ -173,7 +173,7 @@ $result_trees{'node_up_external_node'} = [
           {
             'contents' => [
               {
-                'text' => 'first'
+                'text' => 'chap first'
               }
             ],
             'type' => 'line_arg'
@@ -191,7 +191,14 @@ $result_trees{'node_up_external_node'} = [
               }
             ],
             'extra' => {
-              'spaces_before_argument' => ' '
+              'manual_content' => [
+                {}
+              ]
+            },
+            'info' => {
+              'spaces_before_argument' => {
+                'text' => ' '
+              }
             },
             'type' => 'line_arg'
           },
@@ -208,8 +215,17 @@ $result_trees{'node_up_external_node'} = [
               }
             ],
             'extra' => {
-              'spaces_after_argument' => ' ',
-              'spaces_before_argument' => ' '
+              'manual_content' => [
+                {}
+              ]
+            },
+            'info' => {
+              'spaces_after_argument' => {
+                'text' => ' '
+              },
+              'spaces_before_argument' => {
+                'text' => ' '
+              }
             },
             'type' => 'line_arg'
           },
@@ -226,43 +242,30 @@ $result_trees{'node_up_external_node'} = [
               }
             ],
             'extra' => {
-              'spaces_after_argument' => '
-',
-              'spaces_before_argument' => ' '
+              'manual_content' => [
+                {}
+              ]
+            },
+            'info' => {
+              'spaces_after_argument' => {
+                'text' => '
+'
+              },
+              'spaces_before_argument' => {
+                'text' => ' '
+              }
             },
             'type' => 'line_arg'
           }
         ],
         'cmdname' => 'node',
         'extra' => {
-          'node_content' => [
-            {}
-          ],
-          'nodes_manuals' => [
-            {
-              'node_content' => [
-                {}
-              ],
-              'normalized' => 'first'
-            },
-            {
-              'manual_content' => [
-                {}
-              ]
-            },
-            {
-              'manual_content' => [
-                {}
-              ]
-            },
-            {
-              'manual_content' => [
-                {}
-              ]
-            }
-          ],
-          'normalized' => 'first',
-          'spaces_before_argument' => ' '
+          'normalized' => 'chap-first'
+        },
+        'info' => {
+          'spaces_before_argument' => {
+            'text' => ' '
+          }
         },
         'source_info' => {
           'file_name' => '',
@@ -277,30 +280,25 @@ $result_trees{'node_up_external_node'} = [
     'type' => 'unit'
   }
 ];
-$result_trees{'node_up_external_node'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'extra'}{'menu_entry_description'} = $result_trees{'node_up_external_node'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[3];
-$result_trees{'node_up_external_node'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'node_up_external_node'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[1]{'contents'}[0];
-$result_trees{'node_up_external_node'}[0]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'node_up_external_node'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'node_up_external_node'}[0]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'node_up_external_node'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'node_up_external_node'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'node_up_external_node'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'contents'}[0];
 $result_trees{'node_up_external_node'}[0]{'extra'}{'unit_command'} = $result_trees{'node_up_external_node'}[0]{'contents'}[1];
-$result_trees{'node_up_external_node'}[1]{'contents'}[0]{'extra'}{'node_content'}[0] = $result_trees{'node_up_external_node'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0];
-$result_trees{'node_up_external_node'}[1]{'contents'}[0]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'node_up_external_node'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0];
-$result_trees{'node_up_external_node'}[1]{'contents'}[0]{'extra'}{'nodes_manuals'}[1]{'manual_content'}[0] = $result_trees{'node_up_external_node'}[1]{'contents'}[0]{'args'}[1]{'contents'}[1];
-$result_trees{'node_up_external_node'}[1]{'contents'}[0]{'extra'}{'nodes_manuals'}[2]{'manual_content'}[0] = $result_trees{'node_up_external_node'}[1]{'contents'}[0]{'args'}[2]{'contents'}[1];
-$result_trees{'node_up_external_node'}[1]{'contents'}[0]{'extra'}{'nodes_manuals'}[3]{'manual_content'}[0] = $result_trees{'node_up_external_node'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1];
+$result_trees{'node_up_external_node'}[1]{'contents'}[0]{'args'}[1]{'extra'}{'manual_content'}[0] = $result_trees{'node_up_external_node'}[1]{'contents'}[0]{'args'}[1]{'contents'}[1];
+$result_trees{'node_up_external_node'}[1]{'contents'}[0]{'args'}[2]{'extra'}{'manual_content'}[0] = $result_trees{'node_up_external_node'}[1]{'contents'}[0]{'args'}[2]{'contents'}[1];
+$result_trees{'node_up_external_node'}[1]{'contents'}[0]{'args'}[3]{'extra'}{'manual_content'}[0] = $result_trees{'node_up_external_node'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1];
 $result_trees{'node_up_external_node'}[1]{'extra'}{'unit_command'} = $result_trees{'node_up_external_node'}[1]{'contents'}[0];
 
 $result_texis{'node_up_external_node'} = '@node Top
 
 @menu
-* first::
+* chap first::
 @end menu
 
-@node first, (manual1), (manual2) , (manual3)
+@node chap first, (manual1), (manual2) , (manual3)
 ';
 
 
 $result_texts{'node_up_external_node'} = '
-* first::
+* chap first::
 
 ';
 
@@ -326,7 +324,7 @@ $result_nodes{'node_up_external_node'} = {
               'unit_command' => {
                 'cmdname' => 'node',
                 'extra' => {
-                  'normalized' => 'first'
+                  'normalized' => 'chap-first'
                 },
                 'structure' => {
                   'associated_unit' => {},
@@ -440,7 +438,7 @@ $result_menus{'node_up_external_node'} = {
               'unit_command' => {
                 'cmdname' => 'node',
                 'extra' => {
-                  'normalized' => 'first'
+                  'normalized' => 'chap-first'
                 },
                 'structure' => {
                   'associated_unit' => {},
@@ -541,7 +539,7 @@ $result_elements{'node_up_external_node'} = [
           'menu_child' => {
             'cmdname' => 'node',
             'extra' => {
-              'normalized' => 'first'
+              'normalized' => 'chap-first'
             },
             'structure' => {
               'associated_unit' => {
@@ -630,18 +628,18 @@ $result_elements{'node_up_external_node'}[1] = $result_elements{'node_up_externa
 
 
 $result_directions_text{'node_up_external_node'} = 'element: @node Top
-  Forward: @node first
-  NodeForward: @node first
-  NodeNext: @node first
+  Forward: @node chap first
+  NodeForward: @node chap first
+  NodeNext: @node chap first
   This: @node Top
-element: @node first
+element: @node chap first
   Back: @node Top
   NodeBack: @node Top
   NodeForward: (manual1)
   NodeNext: (manual1)
   NodePrev: (manual2)
   NodeUp: (manual3)
-  This: @node first
+  This: @node chap first
 ';
 
 
@@ -662,6 +660,12 @@ $result_converted{'html'}->{'node_up_external_node'} = '<!DOCTYPE html>
 <meta name="viewport" content="width=device-width,initial-scale=1">
 
 <link href="#Top" rel="start" title="Top">
+<style type="text/css">
+<!--
+a.copiable-link {visibility: hidden; text-decoration: none; line-height: 0em}
+span:hover a.copiable-link {visibility: visible}
+-->
+</style>
 
 
 </head>
@@ -669,17 +673,17 @@ $result_converted{'html'}->{'node_up_external_node'} = '<!DOCTYPE html>
 <body lang="en">
 <a class="node-id" id="Top"></a><div class="nav-panel">
 <p>
-Next: <a href="#first" accesskey="n" rel="next">first</a> &nbsp; </p>
+Next: <a href="#chap-first" accesskey="n" rel="next">chap first</a> &nbsp; </p>
 </div>
-<h1 class="node">Top</h1>
+<h1 class="node"><span>Top<a class="copiable-link" href="#Top"> &para;</a></span></h1>
 
 
 <hr>
-<a class="node-id" id="first"></a><div class="nav-panel">
+<a class="node-id" id="chap-first"></a><div class="nav-panel">
 <p>
 Next: <a href="manual1.html#Top" accesskey="n" rel="next">(manual1)</a>, Previous: <a href="manual2.html#Top" accesskey="p" rel="prev">(manual2)</a>, Up: <a href="manual3.html#Top" accesskey="u" rel="up">(manual3)</a> &nbsp; </p>
 </div>
-<h4 class="node">first</h4>
+<h4 class="node"><span>chap first<a class="copiable-link" href="#chap-first"> &para;</a></span></h4>
 
 
 
@@ -697,4 +701,14 @@ $result_converted_errors{'html'}->{'node_up_external_node'} = [
 ];
 
 
+
+$result_converted{'xml'}->{'node_up_external_node'} = '<node name="Top" spaces=" "><nodename>Top</nodename><nodenext automatic="on">chap first</nodenext></node>
+
+<menu endspaces=" ">
+<menuentry><menuleadingtext>* </menuleadingtext><menunode>chap first</menunode><menuseparator>::</menuseparator><menudescription><pre xml:space="preserve">
+</pre></menudescription></menuentry></menu>
+
+<node name="chap-first" spaces=" "><nodename>chap first</nodename><nodenext spaces=" ">(manual1)</nodenext><nodeprev spaces=" " trailingspaces=" ">(manual2)</nodeprev><nodeup spaces=" ">(manual3)</nodeup></node>
+';
+
 1;
