@@ -19,28 +19,23 @@ $result_trees{'part_node_part_node_appendix'} = [
                 'text' => 'Top'
               }
             ],
-            'extra' => {
-              'spaces_after_argument' => '
+            'info' => {
+              'spaces_after_argument' => {
+                'text' => '
 '
+              }
             },
             'type' => 'line_arg'
           }
         ],
         'cmdname' => 'node',
         'extra' => {
-          'node_content' => [
-            {}
-          ],
-          'nodes_manuals' => [
-            {
-              'node_content' => [
-                {}
-              ],
-              'normalized' => 'Top'
-            }
-          ],
-          'normalized' => 'Top',
-          'spaces_before_argument' => ' '
+          'normalized' => 'Top'
+        },
+        'info' => {
+          'spaces_before_argument' => {
+            'text' => ' '
+          }
         },
         'source_info' => {
           'file_name' => '',
@@ -56,9 +51,11 @@ $result_trees{'part_node_part_node_appendix'} = [
                 'text' => 'top'
               }
             ],
-            'extra' => {
-              'spaces_after_argument' => '
+            'info' => {
+              'spaces_after_argument' => {
+                'text' => '
 '
+              }
             },
             'type' => 'line_arg'
           }
@@ -73,9 +70,11 @@ $result_trees{'part_node_part_node_appendix'} = [
           {
             'args' => [
               {
-                'extra' => {
-                  'spaces_after_argument' => '
+                'info' => {
+                  'spaces_after_argument' => {
+                    'text' => '
 '
+                  }
                 },
                 'type' => 'block_line_arg'
               }
@@ -83,7 +82,7 @@ $result_trees{'part_node_part_node_appendix'} = [
             'cmdname' => 'menu',
             'contents' => [
               {
-                'args' => [
+                'contents' => [
                   {
                     'text' => '* ',
                     'type' => 'menu_entry_leading_text'
@@ -94,6 +93,12 @@ $result_trees{'part_node_part_node_appendix'} = [
                         'text' => 'chapter node'
                       }
                     ],
+                    'extra' => {
+                      'node_content' => [
+                        {}
+                      ],
+                      'normalized' => 'chapter-node'
+                    },
                     'type' => 'menu_entry_node'
                   },
                   {
@@ -115,15 +120,6 @@ $result_trees{'part_node_part_node_appendix'} = [
                     'type' => 'menu_entry_description'
                   }
                 ],
-                'extra' => {
-                  'menu_entry_description' => {},
-                  'menu_entry_node' => {
-                    'node_content' => [
-                      {}
-                    ],
-                    'normalized' => 'chapter-node'
-                  }
-                },
                 'source_info' => {
                   'file_name' => '',
                   'line_nr' => 5,
@@ -132,7 +128,7 @@ $result_trees{'part_node_part_node_appendix'} = [
                 'type' => 'menu_entry'
               },
               {
-                'args' => [
+                'contents' => [
                   {
                     'text' => '* ',
                     'type' => 'menu_entry_leading_text'
@@ -143,6 +139,12 @@ $result_trees{'part_node_part_node_appendix'} = [
                         'text' => 'appendix node'
                       }
                     ],
+                    'extra' => {
+                      'node_content' => [
+                        {}
+                      ],
+                      'normalized' => 'appendix-node'
+                    },
                     'type' => 'menu_entry_node'
                   },
                   {
@@ -164,15 +166,6 @@ $result_trees{'part_node_part_node_appendix'} = [
                     'type' => 'menu_entry_description'
                   }
                 ],
-                'extra' => {
-                  'menu_entry_description' => {},
-                  'menu_entry_node' => {
-                    'node_content' => [
-                      {}
-                    ],
-                    'normalized' => 'appendix-node'
-                  }
-                },
                 'source_info' => {
                   'file_name' => '',
                   'line_nr' => 6,
@@ -188,18 +181,24 @@ $result_trees{'part_node_part_node_appendix'} = [
                         'text' => 'menu'
                       }
                     ],
-                    'extra' => {
-                      'spaces_after_argument' => '
+                    'info' => {
+                      'spaces_after_argument' => {
+                        'text' => '
 '
+                      }
                     },
                     'type' => 'line_arg'
                   }
                 ],
                 'cmdname' => 'end',
                 'extra' => {
-                  'spaces_before_argument' => ' ',
                   'text_arg' => 'menu'
                 },
+                'info' => {
+                  'spaces_before_argument' => {
+                    'text' => ' '
+                  }
+                },
                 'source_info' => {
                   'file_name' => '',
                   'line_nr' => 7,
@@ -219,8 +218,11 @@ $result_trees{'part_node_part_node_appendix'} = [
             'type' => 'empty_line'
           }
         ],
-        'extra' => {
-          'spaces_before_argument' => ' '
+        'extra' => {},
+        'info' => {
+          'spaces_before_argument' => {
+            'text' => ' '
+          }
         },
         'source_info' => {
           'file_name' => '',
@@ -244,9 +246,11 @@ $result_trees{'part_node_part_node_appendix'} = [
                 'text' => 'Part 1'
               }
             ],
-            'extra' => {
-              'spaces_after_argument' => '
+            'info' => {
+              'spaces_after_argument' => {
+                'text' => '
 '
+              }
             },
             'type' => 'line_arg'
           }
@@ -259,8 +263,11 @@ $result_trees{'part_node_part_node_appendix'} = [
             'type' => 'empty_line'
           }
         ],
-        'extra' => {
-          'spaces_before_argument' => ' '
+        'extra' => {},
+        'info' => {
+          'spaces_before_argument' => {
+            'text' => ' '
+          }
         },
         'source_info' => {
           'file_name' => '',
@@ -276,28 +283,23 @@ $result_trees{'part_node_part_node_appendix'} = [
                 'text' => 'chapter node'
               }
             ],
-            'extra' => {
-              'spaces_after_argument' => '
+            'info' => {
+              'spaces_after_argument' => {
+                'text' => '
 '
+              }
             },
             'type' => 'line_arg'
           }
         ],
         'cmdname' => 'node',
         'extra' => {
-          'node_content' => [
-            {}
-          ],
-          'nodes_manuals' => [
-            {
-              'node_content' => [
-                {}
-              ],
-              'normalized' => 'chapter-node'
-            }
-          ],
-          'normalized' => 'chapter-node',
-          'spaces_before_argument' => ' '
+          'normalized' => 'chapter-node'
+        },
+        'info' => {
+          'spaces_before_argument' => {
+            'text' => ' '
+          }
         },
         'source_info' => {
           'file_name' => '',
@@ -313,9 +315,11 @@ $result_trees{'part_node_part_node_appendix'} = [
                 'text' => 'chapter'
               }
             ],
-            'extra' => {
-              'spaces_after_argument' => '
+            'info' => {
+              'spaces_after_argument' => {
+                'text' => '
 '
+              }
             },
             'type' => 'line_arg'
           }
@@ -329,8 +333,12 @@ $result_trees{'part_node_part_node_appendix'} = [
           }
         ],
         'extra' => {
-          'associated_part' => {},
-          'spaces_before_argument' => ' '
+          'associated_part' => {}
+        },
+        'info' => {
+          'spaces_before_argument' => {
+            'text' => ' '
+          }
         },
         'source_info' => {
           'file_name' => '',
@@ -354,9 +362,11 @@ $result_trees{'part_node_part_node_appendix'} = [
                 'text' => 'Part Appendix'
               }
             ],
-            'extra' => {
-              'spaces_after_argument' => '
+            'info' => {
+              'spaces_after_argument' => {
+                'text' => '
 '
+              }
             },
             'type' => 'line_arg'
           }
@@ -369,8 +379,11 @@ $result_trees{'part_node_part_node_appendix'} = [
             'type' => 'empty_line'
           }
         ],
-        'extra' => {
-          'spaces_before_argument' => ' '
+        'extra' => {},
+        'info' => {
+          'spaces_before_argument' => {
+            'text' => ' '
+          }
         },
         'source_info' => {
           'file_name' => '',
@@ -386,28 +399,23 @@ $result_trees{'part_node_part_node_appendix'} = [
                 'text' => 'appendix node'
               }
             ],
-            'extra' => {
-              'spaces_after_argument' => '
+            'info' => {
+              'spaces_after_argument' => {
+                'text' => '
 '
+              }
             },
             'type' => 'line_arg'
           }
         ],
         'cmdname' => 'node',
         'extra' => {
-          'node_content' => [
-            {}
-          ],
-          'nodes_manuals' => [
-            {
-              'node_content' => [
-                {}
-              ],
-              'normalized' => 'appendix-node'
-            }
-          ],
-          'normalized' => 'appendix-node',
-          'spaces_before_argument' => ' '
+          'normalized' => 'appendix-node'
+        },
+        'info' => {
+          'spaces_before_argument' => {
+            'text' => ' '
+          }
         },
         'source_info' => {
           'file_name' => '',
@@ -423,17 +431,23 @@ $result_trees{'part_node_part_node_appendix'} = [
                 'text' => 'Appendix'
               }
             ],
-            'extra' => {
-              'spaces_after_argument' => '
+            'info' => {
+              'spaces_after_argument' => {
+                'text' => '
 '
+              }
             },
             'type' => 'line_arg'
           }
         ],
         'cmdname' => 'appendix',
         'extra' => {
-          'associated_part' => {},
-          'spaces_before_argument' => ' '
+          'associated_part' => {}
+        },
+        'info' => {
+          'spaces_before_argument' => {
+            'text' => ' '
+          }
         },
         'source_info' => {
           'file_name' => '',
@@ -448,19 +462,11 @@ $result_trees{'part_node_part_node_appendix'} = [
     'type' => 'unit'
   }
 ];
-$result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[0]{'extra'}{'menu_entry_description'} = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[3];
-$result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[0]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[1]{'contents'}[0];
-$result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[3];
-$result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0];
+$result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[0];
 $result_trees{'part_node_part_node_appendix'}[0]{'extra'}{'unit_command'} = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2];
-$result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[2]{'extra'}{'associated_part'} = $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[0];
 $result_trees{'part_node_part_node_appendix'}[1]{'extra'}{'unit_command'} = $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[2];
-$result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[2]{'extra'}{'associated_part'} = $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[0];
 $result_trees{'part_node_part_node_appendix'}[2]{'extra'}{'unit_command'} = $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[2];
 
@@ -1252,6 +1258,12 @@ $result_converted{'html'}->{'part_node_part_node_appendix'} = '<!DOCTYPE html>
 <meta name="viewport" content="width=device-width,initial-scale=1">
 
 <link href="#Top" rel="start" title="Top">
+<style type="text/css">
+<!--
+a.copiable-link {visibility: hidden; text-decoration: none; line-height: 0em}
+span:hover a.copiable-link {visibility: visible}
+-->
+</style>
 
 
 </head>
@@ -1262,7 +1274,7 @@ $result_converted{'html'}->{'part_node_part_node_appendix'} = '<!DOCTYPE html>
 <p>
 Next: <a href="#chapter-node" accesskey="n" rel="next">chapter</a> &nbsp; </p>
 </div>
-<h1 class="top" id="top">top</h1>
+<h1 class="top" id="top"><span>top<a class="copiable-link" href="#top"> &para;</a></span></h1>
 
 
 <hr>
@@ -1272,14 +1284,14 @@ Next: <a href="#chapter-node" accesskey="n" rel="next">chapter</a> &nbsp; </p>
 <p>
 Next: <a href="#appendix-node" accesskey="n" rel="next">Appendix</a>, Previous: <a href="#Top" accesskey="p" rel="prev">top</a>, Up: <a href="#Top" accesskey="u" rel="up">top</a> &nbsp; </p>
 </div>
-<h1 class="part">Part 1</h1>
+<h1 class="part"><span>Part 1<a class="copiable-link" href="#Part-1"> &para;</a></span></h1>
 <hr>
 
 <ul class="mini-toc">
 <li><a href="#chapter-node" accesskey="1">chapter</a></li>
 </ul>
 <div class="chapter-level-extent" id="chapter-node">
-<h2 class="chapter" id="chapter">1 chapter</h2>
+<h2 class="chapter" id="chapter"><span>1 chapter<a class="copiable-link" href="#chapter"> &para;</a></span></h2>
 
 <hr>
 </div>
@@ -1289,14 +1301,14 @@ Next: <a href="#appendix-node" accesskey="n" rel="next">Appendix</a>, Previous:
 <p>
 Previous: <a href="#chapter-node" accesskey="p" rel="prev">chapter</a>, Up: <a href="#Top" accesskey="u" rel="up">top</a> &nbsp; </p>
 </div>
-<h1 class="part">Part Appendix</h1>
+<h1 class="part"><span>Part Appendix<a class="copiable-link" href="#Part-Appendix"> &para;</a></span></h1>
 <hr>
 
 <ul class="mini-toc">
 <li><a href="#appendix-node" accesskey="1">Appendix</a></li>
 </ul>
 <div class="appendix-level-extent" id="appendix-node">
-<h2 class="appendix" id="Appendix">Appendix A Appendix</h2>
+<h2 class="appendix" id="Appendix"><span>Appendix A Appendix<a class="copiable-link" href="#Appendix"> &para;</a></span></h2>
 </div>
 </div>
 
@@ -1311,8 +1323,8 @@ $result_converted{'xml'}->{'part_node_part_node_appendix'} = '<node name="Top" s
 <top spaces=" "><sectiontitle>top</sectiontitle>
 
 <menu endspaces=" ">
-<menuentry leadingtext="* "><menunode separator="::">chapter node</menunode><menudescription><pre xml:space="preserve">
-</pre></menudescription></menuentry><menuentry leadingtext="* "><menunode separator="::">appendix node</menunode><menudescription><pre xml:space="preserve">
+<menuentry><menuleadingtext>* </menuleadingtext><menunode>chapter node</menunode><menuseparator>::</menuseparator><menudescription><pre xml:space="preserve">
+</pre></menudescription></menuentry><menuentry><menuleadingtext>* </menuleadingtext><menunode>appendix node</menunode><menuseparator>::</menuseparator><menudescription><pre xml:space="preserve">
 </pre></menudescription></menuentry></menu>
 
 </top>
